#!/bin/bash

export PATH="/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"

function Usage
{
cat << END
*******************************************************************************
* This script is used to append smartcard's detail to pcsc driver's plist file.
	append_smartcard.sh <VID:PID> <manufacturer> <product> <gnusb_dir>
	E.g
	append_smartcard.sh "22fb:1014" "UltraSec USK200" "SMARTCARD READER" "..."
*******************************************************************************

END
	exit
}

function gnlog
{
	cur_date=$(date)
	log_fmt=$*
	echo "${cur_date}:${log_fmt}" >> /tmp/gnccid_autobuild.log
}

function restart_pcsc
{
	killall -9 pcscd
	nohup /usr/sbin/pcscd > /dev/null 2>&1 &
}

function main
{
	[ "$#" -lt 4 ] && Usage
	orig_vpid="$1"
	mfg="$2"
	prod="$3"
	usbdir="$4"
	
	vpid=$(echo ${orig_vpid} | awk -F ":" '{print "0x"$1":0x"$2}')
	gnlog $vpid
	gnlog $usbdir
	
	append_str="${vpid}:${mfg} ${prod}"
	gnlog $append_str
	
	findret=$(cat ${usbdir}/supported_readers.txt 2> /dev/null | grep -i "${append_str}")
	if [[ -z $findret ]]; then
		gnlog "try to append ${append_str} to plist"
		echo $append_str >> ${usbdir}/supported_readers.txt
	else
		gnlog "${append_str} has been exist in plist!!!"
	fi
	${usbdir}/create_Info_plist.pl ${usbdir}/supported_readers.txt ${usbdir}/Info.plist.src --target=libccid.so --version=1.4.34 > ${usbdir}/Info.plist
	cp -rf ${usbdir}/Info.plist ${usbdir}/ccid_1_8_14/lib/pcsc/drivers/ifd-ccid.bundle/Contents/
	cp -rf ${usbdir}/Info.plist ${usbdir}/ccid_1_8_26/lib/pcsc/drivers/ifd-ccid.bundle/Contents/
	mv -f  ${usbdir}/Info.plist ${usbdir}/../../ifd-ccid.bundle/Contents/
	restart_pcsc
	
	return
}

main "$@"
