#!/bin/bash

export PATH="/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"

gnp_flag="gnprinter_"
cutbkcmd='s/\\//g'

function Usage
{
cat << END
******************************************************************************
* This script is used to manage gnprinter. (MUST BE RUNNING AT ROOT MODE)
******************************************************************************

END
	exit
}

function gnlog
{
	cur_date=$(date)
	log_fmt=$*
	echo "${cur_date}:${log_fmt}"
}

function add_gnprinter
{
	remote_printer_name=$*
	if [[ $remote_printer_name != $gnp_flag* ]]; then
		remote_printer_name=`echo "$*" | sed "s/\///g" | sed "s/[[:space:]]//g" | sed $cutbkcmd | sed "s/\'//g" | sed "s/\"//g" | sed "s/\?//g" | sed "s/\#//g"`
		gnprinter_name="gnprinter_$remote_printer_name"
	else
		gnprinter_name=$*
	fi
	lpadmin -p $gnprinter_name -E -v cups-pdf:/ -m CUPS-PDF_opt.ppd > /tmp/setgnprinter.log 2>&1
	
	gnclient_info=$(ps aux 2> /dev/null | grep -n "\<[g]nclient\>")
	if [[ -z $gnclient_info ]]; then
		gnlog "gnclient_NOT_exist"
		cupsreject $gnprinter_name
		cupsdisable $gnprinter_name
	else
		gnlog "gnclient_exist ${gnclient_info}"
	fi	
	gnlog "AT add_gnprinter, try to append printer $gnprinter_name"
}

function del_gnprinter
{
        remote_printer_name=$*
        if [[ $remote_printer_name != $gnp_flag* ]]; then
                remote_printer_name=`echo $* | sed "s/\///g" | sed "s/[[:space:]]//g" | sed $cutbkcmd | sed "s/\'//g" | sed "s/\"//g" | sed "s/\?//g" | sed "s/\#//g"`
                gnprinter_name="gnprinter_$remote_printer_name"
        else
                gnprinter_name=$*
        fi
	lpadmin -x $gnprinter_name > /tmp/setgnprinter.log 2>&1
	gnlog "AT del_gnprinter, try to delete printer $gnprinter_name"
}

function del_all_gnprinter
{
	lpstat -a | grep gnprinter | awk '{print $1}' | while read LINE
	do
		gnlog "del_all_gnprinter:Current try to delete lpadmin $LINE"
		lpadmin -x $LINE
	done
}

function manage_gnprinter_default_settings
{
	return
}

function main
{
	[ "$#" -lt 1 ] && Usage
	case "$1" in
		add_printer)
			[ "$#" -lt 2 ] && Usage
			add_gnprinter $2
			;;
		del_printer)
			[ "$#" -lt 2 ] && Usage
			del_gnprinter $2
			;;
		del_all_printer)
			del_all_gnprinter
			;;
		*)
			Usage
			;;
	esac
	return
}

main "$@"
