#!/bin/bash

export PATH=$PATH:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

hw_info=$(cat /etc/hw_version 2> /dev/null | sed -e 's/[ ][ ]*/_/g')
current_arch=$(uname -m)
path_to_usbip_ko=""
disk_path_to_usbip_ko=""
os=""
is_exist_usbip_ko=""
pack_name=$*

function gnlog
{
	cur_date=$(date)
	log_fmt=$*
	echo "${cur_date}:${log_fmt}"
}

function wait_until_dpkg_return
{
	while true
	do
		ps_ret=$(ps aux 2> /dev/null | grep "[d]pkg -i" | awk '{print (length($0)>10) ? "gnusb_yes" : ""}')
		if [ "$ps_ret" == 'gnusb_yes' ]; then
			gnlog "dpkg is running"
			sleep 1s
		else
			gnlog "dpkg has been exited!"
			break
		fi
	done
}

function install_gcc_at_kylin990
{
	sleep 5s && wait_until_dpkg_return
	i=1
	while ((i <= 10))
	do
		((i++))
		dpkg -i /opt/apps/${pack_name}/files/gnusb/usbip_utils/gcc_uos_kylin990/*.deb && echo "gcc装成功" && break
 		echo "gcc安装失败,3秒后重试"
		sleep 3s
	done
	echo "return from install_gcc_at_kylin990"
}

function install_usbip_dpkg
{
	sleep 2s && wait_until_dpkg_return
	i=1
	while ((i <= 10))
	do
		((i++))
		dpkg -i /opt/apps/${pack_name}/files/gnusb/usbip_utils/`uname -m`/*.deb && echo "usbip装成功" && break
		echo "usbip安装失败，3秒后重试"
		sleep 3s
	done
	echo "return from install_usbip_dpkg"
}

function install_gcc_online
{
	ping www.baidu.com -c 1 > /dev/null 2>&1 || (echo "没有检测到互联网链接！gcc安装失败" && return) 
	sleep 5s
	wait_until_dpkg_return
	apt install -y gcc && gnlog "在线安装gcc成功" || gnlog "在线安装gcc失败！！！"
}

function check_gcc
{
	gcc -v > /dev/null 2>&1 && echo "本系统已安装gcc" && return
	gnlog "本系统未安装gcc，尝试安装"
	if [[ -z $hw_info ]]; then
		gnlog "此系统CPU不是华为麒麟990，尝试在线安装gcc"
		install_gcc_online
	else
		gnlog "此系统CPU是华为麒麟990 代号为${hw_info}"
		install_gcc_at_kylin990
	fi
}

function install_usbip_utils
{
	cd_usbip_install_path=$(cd /opt/apps/${pack_name}/files/gnusb/usbip_utils/`uname -m` 2> /dev/null && echo gnusb_yes)
	if [ "$cd_usbip_install_path" == 'gnusb_yes' ]; then
		gnlog "找到当前架构${current_arch}的usbip-util安装包，开始安装"
		if [ -e "/opt/apps/${pack_name}/files/gnusb/usbip_utils/${current_arch}/usbipd" ]; then
			gnlog "安装自编译usbip_utils"
			ln -s /opt/apps/${pack_name}/files/gnusb/usbip_utils/`uname -m`/usbip /bin/usbip && ln -s /opt/apps/${pack_name}/files/gnusb/usbip_utils/`uname -m`/usbipd /bin/usbipd
			return
		fi
		install_usbip_dpkg
	else
		gnlog "未找到当前架构${current_arch}的usbip-util安装包！usb映射功能可能工作不正常"
	fi
}

function check_usbip_utils
{
	usbip_util_check_cmd=$(usbip version 2> /dev/null | grep "usbip-utils" | awk '{print (length($0)>10) ? "gnusb_yes" : ""}')
	if [ "$usbip_util_check_cmd" == 'gnusb_yes' ]; then
		gnlog "系统中已存在usbip用户模式程序"
	else
		gnlog "系统中不存在usbip用户模式程序，准备按架构进行安装"
		
		deb_pack_name=$pack_name
		gnlog "收到包名${deb_pack_name}"
		install_usbip_utils $deb_pack_name
	fi
	check_gcc
}

function main
{
	current_time=$(date)
	gnlog "${current_time}:开始检测本地usb映射环境"
	check_usbip_utils
	gnlog "${current_time}:usb映射环境检测完毕"
}

trim() {
    str=""
    if [ $# -gt 0 ]; then
        str="$1"
    fi
    echo "$str" | sed -e 's/^[ \t\r\n]*//g' | sed -e 's/[ \t\r\n]*$//g'
}
os=$(trim $(cat /etc/os-release 2>/dev/null | grep ^ID= | awk -F= '{print $2}'))
if [ "$os" = "" ]; then
    os=$(trim $(lsb_release -i 2>/dev/null | awk -F: '{print $2}'))
fi
if [ ! "$os" = "" ]; then
    os=$(echo $os | tr '[A-Z]' '[a-z]')
fi
echo "os=${os}"

main $*
